import java.awt.*;
import java.awt.event.*;
import java.io.*;
import javax.swing.*;

class MainWindow extends JFrame implements ActionListener {
	private static MainWindow mainWindow = new MainWindow();
	
	private Container c;
	
	/*GUIR|[lg*/
	private JPanel exeFilePanel;
	private JLabel exeFileLabel;
	private JTextField exeFileTextField;
	private JButton chooseExeFileButton;
	
	private JPanel demoFilePanel;
	private JLabel demoFileLabel;
	private JTextField demoFileTextField;
	private JButton chooseDemoFileButton;
	
	private JPanel checkBoxPanel;
	private JCheckBox freecamCheckBox;
	private JCheckBox textCheckBox;
	private JCheckBox bmpCheckBox;
	
	private JPanel speedPanel;
	private JLabel speedLabel;
	private JSlider speedSlider;
	
	private JPanel optionPanel;
	
	private JButton playButton;
	
	private String exeFileDirectory = "C:\\Program Files\\Soldat";
	private String demoFileDirectory = "C:\\Program Files\\Soldat\\Demos";
	
	private String demoFileName = "intro.sdm";
	private String iniFileName = "sdp.ini";
	
	private MainWindow() {
		super("SoldatDemoPlayer");
		
		setBounds(100, 100, 450, 380);
		
		initializeComponent();
		
		c = getContentPane();
		c.setLayout(new FlowLayout());
		((FlowLayout)c.getLayout()).setHgap(1000);
		((FlowLayout)c.getLayout()).setVgap(10);
		c.add(exeFilePanel);
		c.add(demoFilePanel);
		c.add(optionPanel);
		c.add(playButton);
		
		this.setResizable(false);
		this.setDefaultCloseOperation(EXIT_ON_CLOSE);
		
		loadFromIniFile();
		
		show();
	}
	
	private void initializeComponent() {
		exeFilePanel = new JPanel(new FlowLayout());
		exeFileLabel = new JLabel("Soldatst@C");
		exeFileTextField = new JTextField("C:\\Program Files\\Soldat\\Soldat.exe", 15);
		chooseExeFileButton = new JButton("t@C̑I");
		exeFilePanel.add(exeFileLabel);
		exeFilePanel.add(exeFileTextField);
		exeFilePanel.add(chooseExeFileButton);
		
		demoFilePanel = new JPanel(new FlowLayout());
		demoFileLabel = new JLabel("SoldatDEMOt@C");
		demoFileTextField = new JTextField("C:\\Program Files\\Soldat\\Demos\\intro.sdm", 15);
		chooseDemoFileButton = new JButton("t@C̑I");
		demoFilePanel.add(demoFileLabel);
		demoFilePanel.add(demoFileTextField);
		demoFilePanel.add(chooseDemoFileButton);
		
		checkBoxPanel = new JPanel(new GridLayout(3, 1, 10, 10));
		freecamCheckBox = new JCheckBox("t[J[h");
		textCheckBox = new JCheckBox("eLXg̕\");
		bmpCheckBox = new JCheckBox("BMPt@Cւ̒o");
		checkBoxPanel.add(freecamCheckBox);
		checkBoxPanel.add(textCheckBox);
		checkBoxPanel.add(bmpCheckBox);
		
		speedPanel = new JPanel(new FlowLayout());
		speedLabel = new JLabel("Xs[hF");
		speedSlider = new JSlider(0, 300, 100);
		speedSlider.setMajorTickSpacing(50);
		speedSlider.setMinorTickSpacing(10);
		speedSlider.setPaintLabels(true);
		speedSlider.setPaintTicks(true);
		speedSlider.setPaintTrack(true);
		speedPanel.add(speedLabel);
		speedPanel.add(speedSlider);
		
		optionPanel = new JPanel(new GridLayout(2, 1, 10, 10));
		optionPanel.add(checkBoxPanel);
		optionPanel.add(speedPanel);
		
		playButton = new JButton("Đ");
		
		chooseExeFileButton.addActionListener(this);
		chooseDemoFileButton.addActionListener(this);
		playButton.addActionListener(this);
	}

	public static MainWindow getInstance() {
		return mainWindow;
	}
	
	public void actionPerformed(ActionEvent e) {
		if(e.getSource() == chooseExeFileButton) {
			JFileChooser fileChooser = new JFileChooser(exeFileDirectory);
		
			fileChooser.setFileFilter(new SoldatExeFileFilter());
			
			int returnVal = fileChooser.showOpenDialog(this);
			if(returnVal == JFileChooser.APPROVE_OPTION) {
				
				exeFileDirectory = fileChooser.getSelectedFile().getParent();
				exeFileTextField.setText(fileChooser.getSelectedFile().getPath());
			}
			
			saveToIniFile();
		} else if(e.getSource() == chooseDemoFileButton) {
			JFileChooser fileChooser = new JFileChooser(demoFileDirectory);
			fileChooser.setFileFilter(new SoldatDemoFileFilter());

			int returnVal = fileChooser.showOpenDialog(this);
			if(returnVal == JFileChooser.APPROVE_OPTION) {
				demoFileDirectory = fileChooser.getSelectedFile().getParent();
				demoFileTextField.setText(fileChooser.getSelectedFile().getPath());
				demoFileName = fileChooser.getSelectedFile().getName();
			}
			
			saveToIniFile();
		} else if(e.getSource() == playButton) {
			String exeFileName = exeFileTextField.getText();

			int freecamMode;
			int speedValue;
			int textMode;
			int bmpMode;
			
			if(freecamCheckBox.isSelected()) {
				freecamMode = 1;
			} else {
				freecamMode = 0;
			}

			speedValue = speedSlider.getValue();
			
			if(textCheckBox.isSelected()) {
				textMode = 0;
			} else {
				textMode = 1;
			}
			
			if(bmpCheckBox.isSelected()) {
				bmpMode = 1;
			} else {
				bmpMode = 0;
			}
			
			SoldatDemoRuntime sdr = new SoldatDemoRuntime(Runtime.getRuntime());
			
			sdr.exeSoldatDemo(exeFileName, demoFileName, freecamMode,
				speedValue, textMode, bmpMode);
		}
	}
	
	public void loadFromIniFile() {
		try {
			FileReader fr = new FileReader(iniFileName);
			BufferedReader br = new BufferedReader(fr);
			
			exeFileDirectory = br.readLine();
			demoFileDirectory = br.readLine();
			
			if(exeFileDirectory == null) {
				exeFileDirectory = "C:\\Program Files\\Soldat";
			}
			
			if(demoFileDirectory == null) {
				demoFileDirectory = "C:\\Program Files\\Soldat\\Demos";
			}
						
			exeFileTextField.setText(exeFileDirectory);
			demoFileTextField.setText(demoFileDirectory);
			
			System.out.println(exeFileDirectory);
			
			fr.close();
			br.close();
		} catch(Exception e) {System.out.println(e);}
	}
	
	public void saveToIniFile() {
		try {
			FileOutputStream fos = new FileOutputStream(iniFileName);
			OutputStreamWriter osw = new OutputStreamWriter(fos , "MS932");
			BufferedWriter bw = new BufferedWriter(osw);
			
			bw.write(exeFileDirectory + "\n");
			bw.write(demoFileDirectory);
			
			bw.flush();
			
			fos.close();
			osw.close();
			bw.close();
		} catch(Exception e) {System.out.println(e);}
	}
}

